package com.muyu.common.nacos.api.interceptor;


import com.dtflys.forest.http.ForestRequest;
import com.dtflys.forest.interceptor.Interceptor;
import com.muyu.common.core.text.Convert;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;

/**
 * @Author：yang
 * @Package：com.muyu.common.nacos.remote.req
 * @Project：cloud-common-nacos-remote
 * @name：BaseReq
 * @Date：2024/8/9 18:10
 */

@Log4j2
public class NacosNamespaceInterceptor<T> implements Interceptor<T> {

    @Value("${nacos.namespace}")
    private String namespaceId;

    /**
     * 该方法在请求发送之前被调用, 若返回false则不会继续发送请求
     * @Param request Forest请求对象
     */
    @Override
    public boolean beforeExecute(ForestRequest req) {
        if (StringUtils.isNotBlank(namespaceId)){
            String reqNamespaceId = Convert.str(req.getQuery("namespaceId"), "");
            if (reqNamespaceId == null){
                log.warn("本次请求nacos的namespaceId未携带，已添加[{}]",namespaceId);
                req.addQuery("namespaceId",namespaceId);

            }else{
                if (StringUtils.equals(reqNamespaceId,namespaceId)){
                    log.warn("本次请求nacos的namespaceId和项目ID不相符，现已更改：[{}->{}]",reqNamespaceId,namespaceId);
                    req.addQuery("namespaceId",namespaceId);
                }
            }
        }
        log.info("invoke Simple beforeExecute"); // 添加Header
        req.addQuery("namespaceId", namespaceId);  // 添加URL的Query参数
        return true;  // 继续执行请求返回true
    }

}

